#
# This file is part of App-Magpie
#
# This software is copyright (c) 2011 by Jerome Quelin.
#
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
#

# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.040.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "Mageia Perl Integration Easy",
  "dist_author" => [
    "Jerome Quelin <jquelin\@gmail.com>"
  ],
  "dist_name" => "App-Magpie",
  "dist_version" => "2.010",
  "license" => "perl",
  "module_name" => "App::Magpie",
  "recursive_test_files" => 1,
  "requires" => {
    "App::Cmd::Setup" => 0,
    "CPAN::Mini" => 0,
    "CPAN::Recent::Uploads" => 0,
    "Config::Tiny" => 0,
    "DateTime" => 0,
    "Encode" => 0,
    "Exporter::Lite" => 0,
    "File::Copy" => 0,
    "File::HomeDir::PathClass" => 0,
    "File::ShareDir" => 0,
    "File::pushd" => 0,
    "Find::Lib" => 0,
    "LWP::Simple" => 0,
    "LWP::UserAgent" => 0,
    "List::AllUtils" => 0,
    "MetaCPAN::Client" => 0,
    "Moose" => 0,
    "Moose::Role" => 0,
    "MooseX::Has::Sugar" => 0,
    "MooseX::SemiAffordanceAccessor" => 0,
    "MooseX::Singleton" => 0,
    "ORDB::CPAN::Mageia" => 0,
    "Parallel::ForkManager" => 0,
    "Parse::CPAN::Meta" => "1.4401",
    "Parse::CPAN::Packages::Fast" => 0,
    "Path::Tiny" => 0,
    "RRDTool::OO" => 0,
    "Readonly" => 0,
    "Template" => 0,
    "Term::ANSIColor" => 0,
    "Text::Padding" => 0,
    "URPM" => 0,
    "perl" => "5.020",
    "strict" => 0,
    "version" => 0,
    "warnings" => 0
  },
  "script_files" => [
    "bin/magpie"
  ],
  "share_dir" => {
    "dist" => "share"
  },
  "test_requires" => {
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::More" => "0.88",
    "blib" => "1.01"
  }
);


my %fallback_build_requires = (
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.3601",
  "Test::More" => "0.88",
  "blib" => "1.01"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
